#!/usr/bin/env python

# This script takes care of compiling all the ".po" translations files into ".mo"
# It has to be run from the root of the BaShare repository, i.e. the files have to be located in "./BaShare/.lang/"
# For more information about BaShare, please visit https://launchpad.net/bashare

import os

# Defining some constants
dotLangFolder = "BaShare/.lang"
translationFileExtension = ".po"

print "Starting to compile BaShare's translation files..."

# Check if the folder exists, i.e. dotLangFolder is a valid folder
if not os.path.isdir(dotLangFolder):
    # The folder does not exist, we are probably not running the script from the root of the repository
    # Exit with an error message
    print "ERROR: Please run this script from the root of the repository."
    exit(-1)
# Get the list of files in the folder
filesInDotLang = os.listdir(dotLangFolder)

# Getting the list of translation files from that folder
languages = []
for f in filesInDotLang:
    if f[-3:] == translationFileExtension:
        # Keep only the files with the correct file extension
        languages.append(f.replace(".po", ""))
if not languages:
    # No file has been kept, exit with an error message
    print "ERROR: There are no '%s' translation files in '%s'" % (translationFileExtension, dotLangFolder)
    exit(-1)

languages.sort() # Sort the languages codes alphabetically
print "\nThe following %d languages have been detected:\n%s" % (len(languages), ", ".join(languages))

print "\nCompiling, please wait..."
for lang in languages:
    # Generate the command that will compile the .po in .mo
    # Obviously, you need to have 'msgfmt' installed on your system...
    command = "msgfmt -o %(folder)s/%(lang)s.mo %(folder)s/%(lang)s.po" % {"folder":dotLangFolder, "lang":lang}
    os.system(command)
    print "%s ---> OK!" % command

print "\nDone!\n"
